@@ -896,9 +896,7 @@ static LONG MSGRemoveContext(SCARDCONTEXT hContext, SCONTEXT * threadContext)
 			{
 				/*
 				 * if the card is locked by someone else we do not reset it
-				 * and simulate a card removal
 				 */
-				rv = SCARD_W_REMOVED_CARD;
 
 				/* decrement card use */
 				(void)SCardDisconnect(hCard, SCARD_LEAVE_CARD);
